@@ -19,8 +19,8 @@ Puppet::Type.newtype(:trove_datastore) do
     end
   end
 
-  validate do
-    raise(Puppet::Error, 'Version must be set') unless self[:version]
+  autorequire(:anchor) do
+    ['trove::service::end']
   end
 end
 
